Struct amazon_sp_services::models::range_capacity::RangeCapacity
source · [−]pub struct RangeCapacity {
pub capacity_type: Option<CapacityType>,
pub slots: Option<Vec<RangeSlot>>,
}Expand description
RangeCapacity : Range capacity entity where each entry has a capacity type and corresponding slots.
Fields
capacity_type: Option<CapacityType>slots: Option<Vec<RangeSlot>>Array of capacity slots in range slot format.
Implementations
sourceimpl RangeCapacity
impl RangeCapacity
sourcepub fn new() -> RangeCapacity
pub fn new() -> RangeCapacity
Range capacity entity where each entry has a capacity type and corresponding slots.